#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SUBS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SUBS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/subs.hpp>

#endif
